#
# spec file for package protobuf (Version 2.3.0)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

%define soname 6

%bcond_without check

%if 0%{?fedora_version} > 8 || 0%{?mandriva_version} > 2008 || 0%{?suse_version} > 1030
%bcond_without protobuf_java
%else
%bcond_with protobuf_java
%endif

%if 0%{?suse_version} > 1100
%bcond_without protobuf_python
%else
%bcond_with protobuf_python
%endif

Name:           protobuf
Summary:        Protocol Buffers - Google's data interchange format
Version:        2.3.0
Release:        1.3
License:        New BSD License
Group:          Development/Libraries/C and C++
Url:            http://code.google.com/p/protobuf/ 
Source0:        http://protobuf.googlecode.com/files/%{name}-%{version}.tar.bz2
Source1:        manifest.txt.in
Patch0:         protobuf-setuptools-2.2.0.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++
%if 0%{?suse_version} > 1010
BuildRequires:  fdupes
%endif
%if %{with protobuf_java}
BuildRequires:  java-devel >= 1.6.0
%endif
%if %{with protobuf_python}
BuildRequires:  python python-devel python-setuptools
%endif

%description
Protocol Buffers are a way of encoding structured data in an efficient yet
extensible format. Google uses Protocol Buffers for almost all of its internal
RPC protocols and file formats. 

%package -n libprotobuf%{soname}


Summary:        Protocol Buffers - Google's data interchange format
Group:          System/Libraries

%description -n libprotobuf%{soname}
Protocol Buffers are a way of encoding structured data in an efficient yet
extensible format. Google uses Protocol Buffers for almost all of its internal
RPC protocols and file formats. 

%package -n libprotoc%{soname}


Summary:        Protocol Buffers - Google's data interchange format
Group:          System/Libraries

%description -n libprotoc%{soname}
Protocol Buffers are a way of encoding structured data in an efficient yet
extensible format. Google uses Protocol Buffers for almost all of its internal
RPC protocols and file formats. 

%package -n libprotobuf-lite%{soname}


Summary:        Protocol Buffers - Google's data interchange format
Group:          System/Libraries

%description -n libprotobuf-lite%{soname}
Protocol Buffers are a way of encoding structured data in an efficient yet
extensible format. Google uses Protocol Buffers for almost all of its internal
RPC protocols and file formats. 

%package devel
License:        New BSD License

Summary:        Header files, libraries and development documentation for %{name}
Group:          Development/Libraries/C and C++
Requires:       gcc-c++

%description devel
Development files for Google Protocol Buffers

%if %{with protobuf_java}

%package -n %{name}-java


Group:          Development/Libraries/Java
Requires:       java >= 1.6.0
Summary:        Java Bindings for Google Protocol Buffers

%description -n %{name}-java
This package contains the Java bindings for Google Protocol Buffers.
%endif

%if %{with protobuf_python}

%package -n python-%{name}


Group:          Development/Libraries/Python
%if 0%{?suse_version}
%py_requires
%else
Requires:       python
%endif
Summary:        Python Bindings for Google Protocol Buffers

%description -n python-%{name}
This package contains the Python bindings for Google Protocol Buffers.
%endif

%prep

%setup -q
%patch0 -p0

%build
%if 0%{?mandriva_version}
#XXX something wents wrong with detecting this
export PTHREAD_LIBS=-lpthread
%endif
%configure --disable-static
%{__make} %{?jobs:-j%jobs}
#
%if %{with protobuf_java}
pushd java
../src/protoc --java_out=src/main/java -I../src ../src/google/protobuf/descriptor.proto
%__mkdir classes
%if 0%{?suse_version} == 1110
# 11.1 only workaround
# http://en.opensuse.org/Java/Packaging/Cookbook#bytecode_version_error
extra_java_flags="-target 1.5"
%endif
javac $extra_java_flags -d classes src/main/java/com/google/protobuf/*.java
sed -e 's/@VERSION@/%version/' < %{SOURCE1} > manifest.txt
jar cfm %{name}-java-%{version}.jar manifest.txt -C classes com
popd
%endif
#
%if %{with protobuf_python}
pushd python
%__python setup.py build
popd
%endif

%if %{with check}

%check
%{__make} check %{?jobs:-j%jobs}
%endif

%install
%makeinstall
%__install -Dm 0644 editors/proto.vim %{buildroot}%{_datadir}/vim/site/syntax/proto.vim  
# no need for that
/bin/rm %{buildroot}%{_libdir}/*.la
#
%if %{with protobuf_java}
pushd java
%__install -D -m 0644 %{name}-java-%{version}.jar %{buildroot}%{_javadir}/%{name}-java-%{version}.jar
%__ln_s %{name}-java-%{version}.jar %{buildroot}%{_javadir}/%{name}-java.jar
%__ln_s %{name}-java-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar
popd
%endif
#
%if %{with protobuf_python}
pushd python
%__python setup.py install --skip-build \
	--prefix=%{_prefix} \
	--install-data=%{_datadir} \
	--root %{buildroot} \
	--record-rpm=INSTALLED_FILES
popd
%endif
#
%if 0%{?suse_version} > 1010
%fdupes %{buildroot}%{py_sitedir}/%{name}-%{version}-py%{py_ver}.egg-info
%endif

%clean
rm -rf $RPM_BUILD_ROOT;

%post -n libprotobuf%{soname} -p /sbin/ldconfig

%postun -n libprotobuf%{soname} -p /sbin/ldconfig

%post -n libprotoc%{soname} -p /sbin/ldconfig

%postun -n libprotoc%{soname} -p /sbin/ldconfig

%post -n libprotobuf-lite%{soname} -p /sbin/ldconfig

%postun -n libprotobuf-lite%{soname} -p /sbin/ldconfig

%files -n libprotobuf%{soname}
%defattr(-, root, root)
%{_libdir}/libprotobuf.so.%{soname}*

%files -n libprotoc%{soname}
%defattr(-, root, root)
%{_libdir}/libprotoc.so.%{soname}*

%files -n libprotobuf-lite%{soname}
%defattr(-, root, root)
%{_libdir}/libprotobuf-lite.so.%{soname}*

%files devel
%defattr(-,root,root)
%doc COPYING.txt 
%doc CHANGES.txt CONTRIBUTORS.txt README.txt
%doc examples
%{_bindir}/protoc
%{_includedir}/google
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_datadir}/vim

%if %{with protobuf_java}

%files -n %{name}-java
%defattr(-,root,root)
%{_javadir}/protobuf*
%endif

%if %{with protobuf_python}

%files -n python-%{name} -f python/INSTALLED_FILES
%defattr(-,root,root)
%endif

%changelog
* Mon Apr 26 2010 lnussel@suse.de
- merge features with version from devel:tools:building
  * build java and python versions
  * disable static libraries
* Sat Apr 24 2010 lnussel@suse.de
- new version 2.3.0
* Sat Apr 24 2010 lnussel@suse.de
- separate soname define
* Mon Dec  7 2009 lnussel@suse.de
- new version 2.2.0a
* Tue Mar 31 2009 lnussel@suse.de
- move protoc to devel package
- split according to library policy
- install vim syntax file
* Tue Sep  2 2008 Lenz Grimmer <lenzg@grimmer.com>
- Update to version 2.0.1
* Tue Aug 12 2008 Lenz Grimmer <lenz@grimmer.com>
- Initial package the openSUSE build service (Version 2.0.0beta)
